GeoException class

Base exception class for all geofence-related errors.

This exception can be used as a catch-all for geofence-specific errors.

Example:

try {
  // geofence operation
} on GeoException catch (e) {
  print('Geofence error: ${e.message}');
}
Implemented types
Implementers

Constructors

GeoException(String message, {String? code, Object? cause})
const

Properties

cause Object?
Optional underlying exception
final
code String?
Optional error code for programmatic handling
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited