CacheKey class

Generates cache keys for marker configurations

Constructors

CacheKey()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forBitmap(MarkerConfig config, {double devicePixelRatio = 1.0}) String
Generates a cache key for a bitmap descriptor
forConfig(MarkerConfig config) String
Generates a unique cache key for a marker configuration
forWidget(MarkerConfig config) String
Generates a cache key for a widget
parseHash(String cacheKey) int?
Parses a cache key to extract configuration hash