MarkerCacheManager class

Cache manager for marker widgets and bitmaps

Uses LRU (Least Recently Used) eviction policy to manage cache size. Separate caches for widgets (Flutter Map) and bitmaps (Google Maps).

Constructors

MarkerCacheManager()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clear() → void
Clear all caches
getCachedBitmapDescriptor(MarkerConfig config) → BitmapDescriptor?
Get a cached BitmapDescriptor for Google Maps
getCachedWidget(MarkerConfig config) Widget?
Get a cached widget for the given configuration
getEstimatedMemoryUsage() int
Get approximate memory usage in bytes
getStats() Map<String, dynamic>
Get cache statistics
putBitmapDescriptor(MarkerConfig config, BitmapDescriptor descriptor) → void
Cache a BitmapDescriptor for Google Maps
putWidget(MarkerConfig config, Widget widget) → void
Cache a widget for the given configuration
remove(MarkerConfig config) → void
Remove specific entry from cache
warmUp(List<MarkerConfig> configs) Future<void>
Warm up the cache with pre-defined configurations