MapProvider enum
Map provider options for displaying geofences.
Determines which map SDK will be used to render the map and geofences.
- Inheritance
- Available extensions
Values
- flutterMap → const MapProvider
-
Use flutter_map package (OpenStreetMap).
This is free and doesn't require an API key. Uses OpenStreetMap tiles.
- googleMap → const MapProvider
-
Use google_maps_flutter package.
Requires a Google Maps API key. Provides more features and better styling options.
- auto → const MapProvider
-
Automatically choose based on availability.
Will use flutter_map if no API key is provided, otherwise will use google_maps_flutter.
Properties
- description → String
-
Available on MapProvider, provided by the MapProviderExtension extension
Returns a description of this provider's requirements.no setter - displayName → String
-
Available on MapProvider, provided by the MapProviderExtension extension
Returns the display name for this map provider.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isFree → bool
-
Available on MapProvider, provided by the MapProviderExtension extension
Whether this provider is free to use (no API costs).no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - requiresApiKey → bool
-
Available on MapProvider, provided by the MapProviderExtension extension
Whether this map provider requires an API key.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MapProvider> - A constant List of the values in this enum, in order of their declaration.