FlutterMapMarkerAdapter class
Marker adapter for FlutterMap (OpenStreetMap)
- Inheritance
-
- Object
- BaseMarkerAdapter
- FlutterMapMarkerAdapter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildBitmapDescriptor(
MarkerConfig config) → Future< BitmapDescriptor> -
Converts a marker configuration to a BitmapDescriptor
override
-
buildCompleteMarker(
{required MarkerConfig config, VoidCallback? onTap, bool isSelected = false}) → Widget -
Creates a complete marker widget with all features
override
-
buildMarker(
MarkerConfig config, {VoidCallback? onTap, bool isSelected = false}) → Widget -
Builds a Flutter widget representing the marker
override
-
buildMarkerWithLabel(
MarkerConfig config, {VoidCallback? onTap, Offset labelOffset = const Offset(0, 8)}) → Widget -
Creates a marker with label positioned below it
override
-
buildMarkerWithLabelInfo(
MarkerConfig config, {VoidCallback? onTap, Offset labelOffset = const Offset(0, 8)}) → Widget - Build marker with label (kept for backward compatibility)
-
createMapMarker(
{required String id, required GeoPoint position, required MarkerConfig config, VoidCallback? onTap}) → Marker - Creates a flutter_map Marker from configuration
-
getHitTestRadius(
MarkerConfig config) → double -
Gets the approximate hit-test radius for the marker
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsMarkerType(
MarkerType type) → bool -
Validates if the adapter supports the given marker type
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited