MarkerLabels class
Factory methods for common label styles
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
text(
String text, {Color? backgroundColor, Color textColor = Colors.white}) → MarkerLabel - Create a label with custom text
Constants
- clean → const MarkerLabel
- Clean white label with no background
- compact → const MarkerLabel
- Small compact label
- dark → const MarkerLabel
- Dark label for light backgrounds
- defaultLabel → const MarkerLabel
- Default white label with semi-transparent black background